@@ -6,7 +6,6 @@ import hashlib
 import itertools
 import os
 import pathlib
-import platform
 import pprint
 import shutil
 import tempfile
@@ -130,6 +129,8 @@ class WheelRepair:
         # Python distribution the wheel targets.
         abi_tags = whl_name_split[-2].split('.')
         platform_tags = whl_name_split[-1].split('.')
+        if 'win32' in platform_tags and 'win_amd64' in platform_tags:
+            raise NotImplementedError('Wheels targeting multiple CPU architectures are not supported')
         ignore_by_distribution = set().union(*dll_list.ignore_by_distribution.values())
         for abi_platform in itertools.product(abi_tags, platform_tags):
             abi_platform = '-'.join(abi_platform)
@@ -152,6 +153,24 @@ class WheelRepair:
             self._wheel_dirs = None
         self._ignore_in_wheel = ignore_in_wheel
 
+        # determine whether wheel is 32-bit or 64-bit
+        self._bitness = None
+        if 'win32' in platform_tags:
+            self._bitness = 32
+        elif 'win_amd64' in platform_tags:
+            self._bitness = 64
+        else:
+            for root, _, filenames in os.walk(self._extract_dir):
+                for filename in filenames:
+                    if filename.lower().endswith('.pyd'):
+                        bitness = patch_dll.get_bitness(os.path.join(root, filename))
+                        if not bitness:
+                            raise NotImplementedError('Wheels for non-x86 architectures are not supported')
+                        elif self._bitness is not None and self._bitness != bitness:
+                            raise NotImplementedError('Wheels targeting multiple CPU architectures are not supported')
+                        self._bitness = bitness
+            self._bitness = 64  # set default value for safety; this shouldn't be used
+
     @staticmethod
     def _rehash(file_path: str) -> typing.Tuple[str, int]:
         """Return (hash, size) for a file with path file_path. The hash and size
@@ -319,7 +338,7 @@ class WheelRepair:
         extension_module_paths = []
         for root, _, filenames in os.walk(self._extract_dir):
             for filename in filenames:
-                if filename.endswith('.pyd'):
+                if filename.lower().endswith('.pyd'):
                     extension_module_path = os.path.join(root, filename)
                     extension_module_paths.append(extension_module_path)
                     discovered, ignored, not_found = patch_dll.get_all_needed(extension_module_path, self._no_dlls, self._wheel_dirs, 'ignore')
@@ -328,10 +347,9 @@ class WheelRepair:
                     not_found_dll_names |= not_found
 
         # find extra dependencies specified with --add-dll
-        interpreter_bitness = 64 if platform.architecture()[0] == '64bit' else 32
         extra_dependency_paths = set()
         for dll_name in self._add_dlls:
-            path = patch_dll.find_library(dll_name, None, interpreter_bitness)
+            path = patch_dll.find_library(dll_name, None, self._bitness)
             if path:
                 extra_dependency_paths.add(path)
             else:
@@ -404,6 +422,9 @@ class WheelRepair:
             for filename in filenames:
                 if filename.lower().endswith('.pyd'):
                     extension_module_path = os.path.join(root, filename)
+                    dll_bitness = patch_dll.get_bitness(extension_module_path)
+                    if dll_bitness != self._bitness:
+                        raise RuntimeError(f'{os.path.relpath(extension_module_path, self._extract_dir)} is {dll_bitness}-bit, which is not allowed in a {self._bitness}-bit wheel')
                     if self._is_top_level_ext_module(extension_module_path):
                         if self._verbose >= 1:
                             print(f'analyzing top-level extension module {os.path.relpath(extension_module_path, self._extract_dir)}')
@@ -431,12 +452,11 @@ class WheelRepair:
         # been found
         dependency_names = {os.path.basename(p) for p in dependency_paths}  # this is NOT lowercased
         dependency_names_lower = {name.lower() for name in dependency_names}
-        interpreter_bitness = 64 if platform.architecture()[0] == '64bit' else 32
         extra_dependency_paths = set()
         for dll_name in self._add_dlls:
             if dll_name in dependency_names_lower:
                 continue
-            path = patch_dll.find_library(dll_name, None, interpreter_bitness)
+            path = patch_dll.find_library(dll_name, None, self._bitness)
             if path:
                 extra_dependency_paths.add(path)
             else:
